==> qtjambi-bluetooth-debuginfo-macos-5.15.18.jar: sources/QtJambiBluetooth/QLowEnergyAdvertisingParameters_AddressInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qlowenergyadvertisingparameters.h>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qlowenergycontroller.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLowEnergyAdvertisingParameters_AddressInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLowEnergyAdvertisingParameters::AddressInfo")
    QLowEnergyAdvertisingParameters::AddressInfo *_ptr = reinterpret_cast<QLowEnergyAdvertisingParameters::AddressInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new AddressInfo()
void __qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AddressInfo()")
    Q_UNUSED(__java_arguments)
    QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = new(__qtjambi_ptr) QLowEnergyAdvertisingParameters::AddressInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)
void __qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)")
    jobject addr0 = __java_arguments[0].l;
    const QBluetoothAddress& __qt_addr0 = qtjambi_cast<const QBluetoothAddress& >(__jni_env, addr0);
    jobject t1 = __java_arguments[1].l;
    QLowEnergyController::RemoteAddressType __qt_t1 = qtjambi_cast<QLowEnergyController::RemoteAddressType>(__jni_env, t1);
    QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = new(__qtjambi_ptr) QLowEnergyAdvertisingParameters::AddressInfo(__qt_addr0, QLowEnergyController::RemoteAddressType(__qt_t1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QLowEnergyAdvertisingParameters::AddressInfo
void __qt_destruct_QLowEnergyAdvertisingParameters_AddressInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLowEnergyAdvertisingParameters::AddressInfo")
    reinterpret_cast<QLowEnergyAdvertisingParameters::AddressInfo*>(ptr)->~AddressInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_initialize_1native__Lio_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0, sizeof(QLowEnergyAdvertisingParameters::AddressInfo), typeid(QLowEnergyAdvertisingParameters::AddressInfo), false, &deleter_QLowEnergyAdvertisingParameters_AddressInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_initialize_1native__Lio_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_2Lio_qt_bluetooth_QBluetoothAddress_2Lio_qt_bluetooth_QLowEnergyController_00024RemoteAddressType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject addr0,
 jobject t1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = addr0;
        arguments[1].l = t1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1, sizeof(QLowEnergyAdvertisingParameters::AddressInfo), typeid(QLowEnergyAdvertisingParameters::AddressInfo), false, &deleter_QLowEnergyAdvertisingParameters_AddressInfo, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLowEnergyAdvertisingParameters::AddressInfo::operator==(QLowEnergyAdvertisingParameters::AddressInfo,QLowEnergyAdvertisingParameters::AddressInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_equals_1native_1cref_1QLowEnergyAdvertisingParameters_1AddressInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID ai21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::operator==(QLowEnergyAdvertisingParameters::AddressInfo,QLowEnergyAdvertisingParameters::AddressInfo)", __qt_this)
        const QLowEnergyAdvertisingParameters::AddressInfo& __qt_ai21 = QtJambiAPI::valueReferenceFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(ai21);
        __java_return_value = (*__qt_this) == __qt_ai21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_setAddress_1native_1cref_1QBluetoothAddress__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QBluetoothAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothAddress>(address0);
        __qt_this->address = __qt_address0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_address_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QBluetoothAddress&  __qt_value = __qt_this->address;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_setType_1native_1cref_1QLowEnergyController_1RemoteAddressType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QLowEnergyController::RemoteAddressType __qt_type0 = qtjambi_cast<QLowEnergyController::RemoteAddressType>(__jni_env, type0);
        __qt_this->type = QLowEnergyController::RemoteAddressType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QLowEnergyController::RemoteAddressType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QLowEnergyAdvertisingParameters_AddressInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QLowEnergyAdvertisingParameters::AddressInfo>("QLowEnergyAdvertisingParameters::AddressInfo", "io/qt/bluetooth/QLowEnergyAdvertisingParameters$AddressInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QLowEnergyAdvertisingParameters_AddressInfo, {
        ConstructorInfo(&__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1, "Lio/qt/bluetooth/QBluetoothAddress;Lio/qt/bluetooth/QLowEnergyController$RemoteAddressType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLowEnergyAdvertisingParameters_AddressInfo);
    registerMetaType<QLowEnergyAdvertisingParameters::AddressInfo>("QLowEnergyAdvertisingParameters::AddressInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-bluetooth-debuginfo-macos-6.6.1.jar: sources/QtJambiBluetooth/QLowEnergyAdvertisingParameters_AddressInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qlowenergyadvertisingparameters.h>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qlowenergycontroller.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLowEnergyAdvertisingParameters_AddressInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLowEnergyAdvertisingParameters::AddressInfo")
    QLowEnergyAdvertisingParameters::AddressInfo *_ptr = reinterpret_cast<QLowEnergyAdvertisingParameters::AddressInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new AddressInfo()
void __qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AddressInfo()")
    Q_UNUSED(__java_arguments)
    QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = new(__qtjambi_ptr) QLowEnergyAdvertisingParameters::AddressInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)
void __qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)")
    jobject addr0 = __java_arguments[0].l;
    const QBluetoothAddress& __qt_addr0 = qtjambi_cast<const QBluetoothAddress& >(__jni_env, addr0);
    jobject t1 = __java_arguments[1].l;
    QLowEnergyController::RemoteAddressType __qt_t1 = qtjambi_cast<QLowEnergyController::RemoteAddressType>(__jni_env, t1);
    QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = new(__qtjambi_ptr) QLowEnergyAdvertisingParameters::AddressInfo(__qt_addr0, QLowEnergyController::RemoteAddressType(__qt_t1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QLowEnergyAdvertisingParameters::AddressInfo
void __qt_destruct_QLowEnergyAdvertisingParameters_AddressInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLowEnergyAdvertisingParameters::AddressInfo")
    reinterpret_cast<QLowEnergyAdvertisingParameters::AddressInfo*>(ptr)->~AddressInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_initialize_1native__Lio_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0, sizeof(QLowEnergyAdvertisingParameters::AddressInfo), typeid(QLowEnergyAdvertisingParameters::AddressInfo), false, &deleter_QLowEnergyAdvertisingParameters_AddressInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_initialize_1native__Lio_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_2Lio_qt_bluetooth_QBluetoothAddress_2Lio_qt_bluetooth_QLowEnergyController_00024RemoteAddressType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject addr0,
 jobject t1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::AddressInfo(QBluetoothAddress,QLowEnergyController::RemoteAddressType)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = addr0;
        arguments[1].l = t1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1, sizeof(QLowEnergyAdvertisingParameters::AddressInfo), typeid(QLowEnergyAdvertisingParameters::AddressInfo), false, &deleter_QLowEnergyAdvertisingParameters_AddressInfo, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLowEnergyAdvertisingParameters::AddressInfo::operator==(QLowEnergyAdvertisingParameters::AddressInfo,QLowEnergyAdvertisingParameters::AddressInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_equals_1native_1cref_1QLowEnergyAdvertisingParameters_1AddressInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID b1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLowEnergyAdvertisingParameters::AddressInfo::operator==(QLowEnergyAdvertisingParameters::AddressInfo,QLowEnergyAdvertisingParameters::AddressInfo)", __qt_this)
        const QLowEnergyAdvertisingParameters::AddressInfo& __qt_b1 = QtJambiAPI::valueReferenceFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(b1);
        __java_return_value = (*__qt_this) == __qt_b1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_setAddress_1native_1cref_1QBluetoothAddress__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QBluetoothAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothAddress>(address0);
        __qt_this->address = __qt_address0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_address_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QBluetoothAddress&  __qt_value = __qt_this->address;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_setType_1native_1cref_1QLowEnergyController_1RemoteAddressType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QLowEnergyController::RemoteAddressType __qt_type0 = qtjambi_cast<QLowEnergyController::RemoteAddressType>(__jni_env, type0);
        __qt_this->type = QLowEnergyController::RemoteAddressType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QLowEnergyController::RemoteAddressType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QLowEnergyAdvertisingParameters_00024AddressInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QLowEnergyAdvertisingParameters::AddressInfo *__qt_this = QtJambiAPI::objectFromNativeId<QLowEnergyAdvertisingParameters::AddressInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QLowEnergyAdvertisingParameters_AddressInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QLowEnergyAdvertisingParameters::AddressInfo>("QLowEnergyAdvertisingParameters::AddressInfo", "io/qt/bluetooth/QLowEnergyAdvertisingParameters$AddressInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QLowEnergyAdvertisingParameters_AddressInfo, {
        ConstructorInfo(&__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QLowEnergyAdvertisingParameters_AddressInfo_1, "Lio/qt/bluetooth/QBluetoothAddress;Lio/qt/bluetooth/QLowEnergyController$RemoteAddressType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLowEnergyAdvertisingParameters_AddressInfo);
    registerMetaType<QLowEnergyAdvertisingParameters::AddressInfo>("QLowEnergyAdvertisingParameters::AddressInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
